#!/usr/bin/env python

from base64 import b64decode
import typer
import kr8s
from kr8s.objects import new_class

app = typer.Typer()

@app.command()
def main(
  user_name: str = typer.Argument(), 
  namespace: str = typer.Option(default=kr8s.ALL),
):
    """Retrieve an s3 user by name (and namespace) and print it's credentials"""

    CephObjectStoreUser = new_class(
        kind="CephObjectStoreUser",
        version="ceph.rook.io/v1",
        namespaced=True,
        scalable=False,
        asyncio=False,
    )
    user, = kr8s.get("CephObjectStoreUser", user_name, namespace=namespace)
    secret_name = user.status.info.secretName
    secret, = kr8s.get("secret", secret_name, namespace=namespace)

    print("Endpoint: ", b64decode(secret.data["Endpoint"]).decode())
    print("KeyId:    ", b64decode(secret.data["AccessKey"]).decode())
    print("SecretKey:", b64decode(secret.data["SecretKey"]).decode())
